@@ -31,7 +31,7 @@ public:
 private slots:
     void on_horizontalSlider_valueChanged(int value);
 
-    void on_method1_toggled(bool checked);
+    void on_method1_toggled();
     void setColor(const QColor &color, QWidget *colorLabel);
     void showColorDialog(QWidget *colorLabel);
     QColor getColorFromLabel(QWidget *colorLabel) const;
