@@ -178,23 +178,34 @@ void prefsDialog::on_compressionSlider_sliderMoved(int position)
     ui->compressionValue->setText(val);
 }
 
+void prefsDialog::on_compressionSlider_valueChanged(int value)
+{
+    QString val = QString::number(value);
+    ui->compressionValue->setText(val);
+}
+
 void prefsDialog::on_historySlider_sliderMoved(int position)
 {
     QString val = QString::number(position);
     ui->history_value->setText(val);
 }
 
+void prefsDialog::on_historySlider_valueChanged(int value)
+{
+    QString val = QString::number(value);
+    ui->history_value->setText(val);
+}
+
 void prefsDialog::on_restartButton_clicked()
 {
     // Save language before we quit
     set_user_language();
 
     qApp->quit();
-    QProcess* proc = new QProcess();
-    proc->start(QCoreApplication::applicationFilePath());
+    QProcess::startDetached(QCoreApplication::applicationFilePath());
 }
 
-void prefsDialog::on_comboBoxLanguage_currentIndexChanged(const QString &arg1)
+void prefsDialog::on_comboBoxLanguage_currentIndexChanged()
 {
     ui->restartButton->show();
 }
