@@ -36,10 +36,14 @@ private slots:
 
     void set_user_language();
 
-    void on_comboBoxLanguage_currentIndexChanged(const QString &arg1);
+    void on_comboBoxLanguage_currentIndexChanged();
 
     void on_buttonBox_rejected();
 
+    void on_compressionSlider_valueChanged(int value);
+
+    void on_historySlider_valueChanged(int value);
+
 private:
     Ui::prefsDialog *ui;
     QString flagPath;
