@@ -348,7 +348,7 @@ void MainWindow::on_actionOpen_triggered()
     {
         for(int i=0;i<fileName.length();i++)
         {
-            openFile(fileName[i], false);
+            openFile(fileName[i]);
         }
 
         if(SETTINGS->getPreviouslyOpened() == true)
@@ -379,7 +379,7 @@ QString MainWindow::prepareFile(const QString& fileName)
     QImageReader reader(fileName);
     reader.setDecideFormatFromContent(true); // Autodetect file type without depending on extension
 
-    if(info.completeSuffix() != "jpg" && info.completeSuffix() != reader.format() && fileTypeSupported(reader.supportedImageFormats(),reader.format()))
+    if(info.completeSuffix().toLower() != "jpg" && info.completeSuffix() != reader.format() && fileTypeSupported(reader.supportedImageFormats(),reader.format()))
     {
         int ret = QMessageBox::warning(this,
                     tr("Incorrect file extension detected"),
@@ -406,7 +406,7 @@ QString MainWindow::prepareFile(const QString& fileName)
     return newFileName;
 }
 
-void MainWindow::openFile(const QString& fileName, bool direct)
+void MainWindow::openFile(const QString& fileName)
 {
     if(!fileExists(fileName))
     {
@@ -429,7 +429,7 @@ void MainWindow::handleMessage(const QString& message)
 {
     QFileInfo fileInfo(message);
     if(fileInfo.exists())
-        openFile(QString(fileInfo.absoluteFilePath()),true);
+        openFile(QString(fileInfo.absoluteFilePath()));
 }
 
 void MainWindow::on_actionRevert_triggered()
@@ -461,7 +461,7 @@ void MainWindow::updateRecentFilesMenu()
         {
             QAction* action = ui->menuRecent_Files->addAction(fileName);
             connect(action, &QAction::triggered, [this, fileName] () {
-                openFile(fileName,false);
+                openFile(fileName);
             });
         }
     }
@@ -539,7 +539,7 @@ void MainWindow::on_actionSave_As_triggered()
 
         int quality = -1;
 
-        if(SETTINGS->getCompressionDialogEnabled() && fileNameSuffix == "jpg" || fileNameSuffix == "jpeg")
+        if(SETTINGS->getCompressionDialogEnabled() && (fileNameSuffix == "jpg" || fileNameSuffix == "jpeg"))
         {
             CompressionDialog dlg;
             dlg.exec();
@@ -757,6 +757,7 @@ void MainWindow::on_actionPaste_triggered()
 
 void MainWindow::on_actionPaste_as_new_image_triggered()
 {
+    on_actionCopy_triggered();
     PaintWidget *widget = getCurrentPaintWidget();
     QClipboard *clipboard = QApplication::clipboard();
     if(clipboard->mimeData()->hasImage())
@@ -871,10 +872,11 @@ void MainWindow::on_actionImage_Size_triggered()
     dialog.setWindowTitle("Resize Image");
     dialog.setMode(NewDialog::ResizeImage);
     dialog.setImageSize(widget->image().size());
-    if (dialog.exec())
+    if (dialog.exec() == QDialog::Accepted)
+    {
         widget->setImage(widget->image().scaled(dialog.newImageSize()));
-
-    updateStatusArea(dialog.newImageSize().width(),dialog.newImageSize().height());
+        updateStatusArea(dialog.newImageSize().width(),dialog.newImageSize().height());
+    }
 }
 
 void MainWindow::on_actionCanvas_Size_triggered()
@@ -1429,6 +1431,10 @@ void MainWindow::on_actionShow_grid_triggered()
                 widget->showGrid(i);
                 ui->actionShow_grid->setChecked(true);
             }
+            else
+            {
+                ui->actionShow_grid->setChecked(false);
+            }
         }
         else
         {
@@ -1436,11 +1442,40 @@ void MainWindow::on_actionShow_grid_triggered()
             ui->actionShow_grid->setChecked(false);
         }
     }
+    else
+    {
+        ui->actionShow_grid->setChecked(false);
+    }
+}
+
+void MainWindow::getNextZoomFromScale(QString scaletext)
+{
+    int count = this->zoomCombo->count();
+    for(int i=1;i<count;i++)
+    {
+        int a = this->zoomCombo->itemText(i).replace("%","").toInt();
+        int b = scaletext.replace("%","").toInt();
+
+        if(a > b)
+        {
+            this->zoomCombo->setCurrentIndex(i-1);
+            break;
+        }
+    }
 }
 
 void MainWindow::on_actionZoom_in_triggered()
 {
-    this->zoomCombo->setCurrentIndex(this->zoomCombo->currentIndex()+1);
+    if(this->zoomCombo->currentIndex()==0)
+    {
+        getNextZoomFromScale(this->zoomCombo->currentText());
+    }
+
+    if(this->zoomCombo->currentIndex()+1 < this->zoomCombo->count() && this->zoomCombo->currentIndex()>0)
+    {
+        this->zoomCombo->setCurrentIndex(this->zoomCombo->currentIndex()+1);
+    }
+
     if(this->zoomCombo->currentText() == "")
     {
         this->zoomCombo->setCurrentIndex(this->zoomCombo->currentIndex()+1);
@@ -1455,7 +1490,7 @@ void MainWindow::on_actionZoom_in_triggered()
 
 void MainWindow::on_actionZoom_out_triggered()
 {
-    if(this->zoomCombo->currentIndex() > 0)
+    if(this->zoomCombo->currentIndex()-1 > 1)
     {
         this->zoomCombo->setCurrentIndex(this->zoomCombo->currentIndex()-1);
     }
@@ -1702,7 +1737,7 @@ void MainWindow::on_actionCrop_triggered()
     if (widget)
     {
         MOUSE_POINTER->onCrop();
-        widget->onSelectionChanged(QRect());
+        widget->onSelectionChanged(QPolygon());
     }
 }
 
@@ -2217,6 +2252,9 @@ void MainWindow::createKeyboardShortcuts()
     ui->actionCrop->setShortcut(QString("Ctrl+Shift+H"));
     //View Menu
     ui->actionToolpalette->setShortcut(QString("Ctrl+L"));
+    ui->actionZoom_in->setShortcut(QKeySequence::ZoomIn);
+    ui->actionZoom_out->setShortcut(QKeySequence::ZoomOut);
+    ui->actionFull_screen->setShortcut(QString("Ctrl+F"));
 }
 
 /*
@@ -2425,10 +2463,6 @@ bool MainWindow::eventFilter(QObject * obj, QEvent * e)
             subWindow->widget()->deleteLater();
             break;
         }
-        case QEvent::LanguageChange:
-        {
-            ui->retranslateUi(this);
-        }
         default:
             qt_noop();
     }
