@@ -45,7 +45,7 @@ public:
     ~MainWindow();
 
     PaintWidget* getCurrentPaintWidget();
-    void openFile(const QString& fileName, bool direct);
+    void openFile(const QString& fileName);
 
 public slots:
     void handleMessage(const QString& message);
@@ -212,6 +212,7 @@ private slots:
 
     QString prepareFile(const QString& fileName);
     bool fileTypeSupported(QList<QByteArray> formats, QString ext);
+    void getNextZoomFromScale(QString scaletext);
 
 protected:
     void closeEvent(QCloseEvent *event);
