@@ -16,7 +16,7 @@ public:
     void onMouseMove(const QPoint &pos) override;
     void onMouseRelease(const QPoint &pos) override;
 
-    QCursor getCursor();
+    QCursor getCursor() override;
 public slots:
     void setPrimaryColor(const QColor &color);
     void setSecondaryColor(const QColor &color);
