@@ -9,10 +9,7 @@
 #include <QLabel>
 #include <QPainter>
 #include <QScrollBar>
-#include <QMouseEvent>
-#include <QGraphicsView>
 #include <QGraphicsScene>
-#include <QGraphicsPixmapItem>
 #include <QGraphicsSceneMouseEvent>
 #include <QGraphicsProxyWidget>
 #include <QImageReader>
@@ -21,7 +18,6 @@
 #include "./Tool.h"
 
 #include "QProgressIndicator.h"
-#include "src/Settings.h"
 
 class PaintWidgetPrivate : public QGraphicsScene
 {
@@ -37,7 +33,6 @@ public:
 
         isSelectionVisible = true;
         hotspotVisible = false;
-        selection = QRect();
     }
     ~PaintWidgetPrivate()
     {
@@ -184,7 +179,7 @@ public:
         if (currentTool)
         {
             currentTool->onMouseRelease(QPoint(event->scenePos().x(), event->scenePos().y()));
-            if(imageChanged)
+            if(q->selection().size()==0 && imageChanged)
             {
                 q->onContentChanged();
                 q->contentChanged();
